pub struct Link {
pub info: IdentityPacket,
pub pair_state: PairState,
/* private fields */
}Expand description
A structure representing a peer device linked to this device but not necessarily paired.
Fields
info: IdentityPacketDevice information about this linked remote device.
pair_state: PairStateThe pairing state between the current device and the linked remote device.
Implementations
Sourceimpl Link
impl Link
Sourcepub async fn send(&self, packet: NetworkPacket)
pub async fn send(&self, packet: NetworkPacket)
Send a NetworkPacket to the linked device.