NetworkPacketType

Enum NetworkPacketType 

pub enum NetworkPacketType {
Show 43 variants Identity, Pair, Battery, Clipboard, ClipboardConnect, ConnectivityReport, ContactsRequestAllUidsTimestamps, ContactsRequestVcardByUid, ContactsResponseUidsTimestamps, ContactsResponseVcards, DigitizerSession, Digitizer, FindmyphoneRequest, Lock, LockRequest, MousepadEcho, MousepadKeyboardState, MousepadRequest, Mpris, MprisRequest, Notification, NotificationAction, NotificationReply, NotificationRequest, Ping, Presenter, RunCommand, RunCommandRequest, Sftp, SftpRequest, ShareRequest, ShareRequestUpdate, SmsAttachmentFile, SmsMessages, SmsRequest, SmsRequestAttachment, SmsRequestConversation, SmsRequestConversations, SystemVolume, SystemVolumeRequest, Telephony, TelephonyRequestMute, Other(String),
}
The type of a NetworkPacket.

It’s used to define which packet types are supported by a plugin, see Plugin::supported_incoming_packets and Plugin::supported_outgoing_packets.

Variants



Identity

The KDE Connect identity packet is used to identify devices and their capabilities.



Pair

The KDE Connect pair packet is used to negotiate pairing between devices.



Battery

This packet is a battery status update.



Clipboard

This packet is sent when the clipboard content changes. In other words, it is typically sent when the selection owner changes.



ClipboardConnect

This packet is only sent when a device connects and allows syncing clipboard text content between devices.



ConnectivityReport

This packet allows a device to expose the status of its connectivity.



ContactsRequestAllUidsTimestamps

This packet is a request for a list of contact UIDs with modification timestamps.



ContactsRequestVcardByUid

This packet is a request for a list of contact UIDs with vCard data.



ContactsResponseUidsTimestamps

This packet is a list of contact UIDs with modification timestamps.



ContactsResponseVcards

This packet is a list of contact UIDs with vCard data.



DigitizerSession

This packet either starts or stops a drawing tablet session. The session is started when this packet is sent with a start action. When it is started, it includes the information necessary to create a fake drawing tablet device on the receiver. The session is ended when this packet is sent with an end action, or the device disconnects. It is valid to send both a start or an end packet regardless whether a session exists or not. If a session exists and a start packet is sent, the session will be first ended, and then another session will be started. If no session exists and an end packet is sent, nothing will happen.



Digitizer

This packet is a stylus (or finger) event. kdeconnect.digitizer packets must not be sent until a session has been started. You may start a session by sending the kdeconnect.digitizer.session packet with the field action set to start, and filling the appropriate fields.



FindmyphoneRequest

This packet is a request for a device to announce its location. By convention, sending a second packet cancels the request.



Lock

This packet is a lock status update.



LockRequest

This packet is a request for a lock status update or change.



MousepadEcho

This packet is an echo for a kdeconnect.mousepad.request packet.



MousepadKeyboardState

This packet is a keyboard status update.



MousepadRequest

This packet is a request for a pointer or keyboard event.



Mpris

This packet is used for two things: if it contains a playerList field, it is used to enumerate the available media players to a remote device; if it contains a player field, it is used to report the status of a specific media player. Note that player packets can be incremental, ie: only contain the fields that changed since the last update.



MprisRequest

This packet is used to request the status of remote media players, issue commands, and request the transfer of album art payloads.



Notification

This packet is a notification.



NotificationAction

This packet is an activation of a notification action.



NotificationReply

This packet is a reply for a repliable notification.



NotificationRequest

This packet is a request for notifications.



Ping

This packet is a ping request.



Presenter

This packet is a presentation remote event.



RunCommand

This packet is a list of available commands.



RunCommandRequest

This packet is a runcommand status update.



Sftp

This packet contains SFTP login information.



SftpRequest

This packet is a request to start SFTP.



ShareRequest

This packet is an upload request.



ShareRequestUpdate

This packet is the metadata for a multi-file transfer. By convention it is sent in advance of the packets containing the payload, which will include the same fields, potentially with updated totals.



SmsAttachmentFile

This packet is a message attachment transfer.



SmsMessages

This packet is a list of messages.



SmsRequest

This packet is a request to send an SMS/MMS message.



SmsRequestAttachment

This packet is a request for a message attachment.



SmsRequestConversation

This packet is a request for messages from a thread.



SmsRequestConversations

This packet is a request for the latest message in each thread.



SystemVolume

This packet is a mixer stream state update.



SystemVolumeRequest

This packet is a audio stream request. It is used to request both the list of streams and changes to those streams.



Telephony

This packet is a telephony event, such as the phone ringing.



TelephonyRequestMute

This packet is sent to request the ringer be muted.



Other(String)

Another type of packet that a library user can implement to handle special custom actions.