pub struct NotificationPacket {Show 14 fields
pub id: String,
pub is_cancel: Option<bool>,
pub is_clearable: Option<bool>,
pub silent: Option<bool>,
pub time: Option<String>,
pub app_name: String,
pub ticker: String,
pub title: String,
pub text: String,
pub group_name: Option<String>,
pub payload_hash: Option<String>,
pub conversation: Option<Vec<NotificationMessage>>,
pub actions: Option<Vec<String>>,
pub request_reply_id: Option<String>,
}Expand description
This packet is a notification.
https://invent.kde.org/network/kdeconnect-meta/blob/master/protocol.md#kdeconnectnotification
Fields
id: StringThe notification ID.
is_cancel: Option<bool>If true the notification with the indicated ID has been closed.
is_clearable: Option<bool>If true the notification with the indicated ID can be closed.
silent: Option<bool>If true the notification is preexisting, otherwise the remote device just received it.
time: Option<String>A UNIX epoch timestamp (ms) in string form.
app_name: StringThe notifying application name.
ticker: StringThe notification title and text in a single string.
title: StringThe notification title.
text: StringThe notification body.
group_name: Option<String>The group name if the notification is a conversation message coming from a group.
payload_hash: Option<String>An MD5 hash of the notification icon. If the packet contains this field, it will be accompanied by payload transfer information.
conversation: Option<Vec<NotificationMessage>>A list of messages in the notification if it’s a conversation.
actions: Option<Vec<String>>A list of action names for the notification. Respond with kdeconnect.notification.action to activate.
request_reply_id: Option<String>The UUID for repliable notifications (eg. chat). Respond with kdeconnect.notification.reply to reply.