pub struct RunCommandRequestPacket {
pub key: Option<String>,
pub request_command_list: Option<bool>,
}Expand description
This packet is a runcommand status update.
https://invent.kde.org/network/kdeconnect-meta/blob/master/protocol.md#kdeconnectruncommandrequest
Fields
key: Option<String>If the packet body contains this field it is a request to execute the command with the ID key.
request_command_list: Option<bool>If the packet body contains this field it is a request for the command list.