pub struct ShareRequestUpdatePacket {
pub number_of_files: Option<u64>,
pub total_payload_size: Option<u64>,
}Expand description
This packet is the metadata for a multi-file transfer. By convention it is sent in advance of the packets containing the payload, which will include the same fields, potentially with updated totals.
https://invent.kde.org/network/kdeconnect-meta/blob/master/protocol.md#kdeconnectsharerequestupdate
Fields
number_of_files: Option<u64>Number of files in a multi-file transfer.
total_payload_size: Option<u64>Total size in bytes of a multi-file transfer.