pub struct SystemVolumeRequestPacket {
pub request_sinks: Option<bool>,
pub name: Option<String>,
pub enabled: Option<bool>,
pub muted: Option<bool>,
pub volume: Option<u64>,
}Expand description
This packet is a audio stream request. It is used to request both the list of streams and changes to those streams.
https://invent.kde.org/network/kdeconnect-meta/blob/master/protocol.md#kdeconnectsystemvolumerequest
Fields
request_sinks: Option<bool>Indicates this is a request for the stream list.
name: Option<String>The name of a stream. If the packet contains this field, it is a request to adjust a stream.
enabled: Option<bool>Indicates the stream should become the active default. Always true if present.
muted: Option<bool>The requested mute state.
volume: Option<u64>The requested volume. The maximum value is provided by the maxVolume field of the stream.